==> haskell-colour-2.3.5-188-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colour
version:              2.3.5
visibility:           public
id:                   colour-2.3.5-6IgISjVABr17DDXvEVpmLi
key:                  colour-2.3.5-6IgISjVABr17DDXvEVpmLi
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  60ed6543413252c4c6b61a7770d588af
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-8.10.5/site-local/colour-2.3.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/colour-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.5-6IgISjVABr17DDXvEVpmLi
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.5-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colour
version:              2.3.5
visibility:           public
id:                   colour-2.3.5-408TcGs5I9SCembFk0PxU3
key:                  colour-2.3.5-408TcGs5I9SCembFk0PxU3
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  d99bbbeef32cc99fd002953f34d9b1a6
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.0.1/site-local/colour-2.3.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/colour-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.5-408TcGs5I9SCembFk0PxU3
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
